@@ -22,7 +22,7 @@
 
 # ----------------------------------------------------------------------------
 
-__version__ = '2.1.72'
+__version__ = '2.1.78'
 
 # ----------------------------------------------------------------------------
 
@@ -136,8 +136,6 @@ from ccxt.digifinex import digifinex                                  # noqa: F4
 from ccxt.exmo import exmo                                            # noqa: F401
 from ccxt.flowbtc import flowbtc                                      # noqa: F401
 from ccxt.fmfwio import fmfwio                                        # noqa: F401
-from ccxt.ftx import ftx                                              # noqa: F401
-from ccxt.ftxus import ftxus                                          # noqa: F401
 from ccxt.gate import gate                                            # noqa: F401
 from ccxt.gateio import gateio                                        # noqa: F401
 from ccxt.gemini import gemini                                        # noqa: F401
@@ -179,7 +177,6 @@ from ccxt.qtrade import qtrade                                        # noqa: F4
 from ccxt.ripio import ripio                                          # noqa: F401
 from ccxt.stex import stex                                            # noqa: F401
 from ccxt.therock import therock                                      # noqa: F401
-from ccxt.tidebit import tidebit                                      # noqa: F401
 from ccxt.tidex import tidex                                          # noqa: F401
 from ccxt.timex import timex                                          # noqa: F401
 from ccxt.tokocrypto import tokocrypto                                # noqa: F401
@@ -258,8 +255,6 @@ exchanges = [
     'exmo',
     'flowbtc',
     'fmfwio',
-    'ftx',
-    'ftxus',
     'gate',
     'gateio',
     'gemini',
@@ -301,7 +296,6 @@ exchanges = [
     'ripio',
     'stex',
     'therock',
-    'tidebit',
     'tidex',
     'timex',
     'tokocrypto',
