@@ -2,7 +2,7 @@
 
 # -----------------------------------------------------------------------------
 
-__version__ = '2.1.72'
+__version__ = '2.1.78'
 
 # -----------------------------------------------------------------------------
 
@@ -904,6 +904,14 @@ class Exchange(BaseExchange):
             result.append(self.symbol(symbols[i]))
         return result
 
+    def market_codes(self, codes):
+        if codes is None:
+            return codes
+        result = []
+        for i in range(0, len(codes)):
+            result.append(self.common_currency_code(codes[i]))
+        return result
+
     def parse_bids_asks(self, bidasks, priceKey=0, amountKey=1):
         bidasks = self.to_array(bidasks)
         result = []
