@@ -4,7 +4,7 @@
 
 # ----------------------------------------------------------------------------
 
-__version__ = '2.1.72'
+__version__ = '2.1.78'
 
 # ----------------------------------------------------------------------------
 
@@ -38,8 +38,6 @@ from ccxt.pro.cryptocom import cryptocom                                  # noqa
 from ccxt.pro.currencycom import currencycom                              # noqa: F401
 from ccxt.pro.deribit import deribit                                      # noqa: F401
 from ccxt.pro.exmo import exmo                                            # noqa: F401
-from ccxt.pro.ftx import ftx                                              # noqa: F401
-from ccxt.pro.ftxus import ftxus                                          # noqa: F401
 from ccxt.pro.gate import gate                                            # noqa: F401
 from ccxt.pro.gateio import gateio                                        # noqa: F401
 from ccxt.pro.hitbtc import hitbtc                                        # noqa: F401
@@ -87,8 +85,6 @@ exchanges = [
     'currencycom',
     'deribit',
     'exmo',
-    'ftx',
-    'ftxus',
     'gate',
     'gateio',
     'hitbtc',
